# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.sidecar_error_mode import SidecarErrorMode
from bitmovin_api_sdk.models.sidecar_file import SidecarFile
from bitmovin_api_sdk.models.web_vtt_sidecar_file_segmentation import WebVttSidecarFileSegmentation
import pprint
import six


class WebVttSidecarFile(SidecarFile):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_id=None,
                 input_path=None,
                 outputs=None,
                 error_mode=None,
                 segmentation=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, list[EncodingOutput], SidecarErrorMode, WebVttSidecarFileSegmentation) -> None
        super(WebVttSidecarFile, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, input_id=input_id, input_path=input_path, outputs=outputs, error_mode=error_mode)

        self._segmentation = None
        self.discriminator = None

        if segmentation is not None:
            self.segmentation = segmentation

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(WebVttSidecarFile, self), 'openapi_types'):
            types = getattr(super(WebVttSidecarFile, self), 'openapi_types')

        types.update({
            'segmentation': 'WebVttSidecarFileSegmentation'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(WebVttSidecarFile, self), 'attribute_map'):
            attributes = getattr(super(WebVttSidecarFile, self), 'attribute_map')

        attributes.update({
            'segmentation': 'segmentation'
        })
        return attributes

    @property
    def segmentation(self):
        # type: () -> WebVttSidecarFileSegmentation
        """Gets the segmentation of this WebVttSidecarFile.


        :return: The segmentation of this WebVttSidecarFile.
        :rtype: WebVttSidecarFileSegmentation
        """
        return self._segmentation

    @segmentation.setter
    def segmentation(self, segmentation):
        # type: (WebVttSidecarFileSegmentation) -> None
        """Sets the segmentation of this WebVttSidecarFile.


        :param segmentation: The segmentation of this WebVttSidecarFile.
        :type: WebVttSidecarFileSegmentation
        """

        if segmentation is not None:
            if not isinstance(segmentation, WebVttSidecarFileSegmentation):
                raise TypeError("Invalid type for `segmentation`, type has to be `WebVttSidecarFileSegmentation`")

        self._segmentation = segmentation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(WebVttSidecarFile, self), "to_dict"):
            result = super(WebVttSidecarFile, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebVttSidecarFile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.live_encoding_heartbeat_webhook import LiveEncodingHeartbeatWebhook
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_encoding_heartbeat.live_encoding_heartbeat_webhook_list_query_params import LiveEncodingHeartbeatWebhookListQueryParams


class LiveEncodingHeartbeatApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveEncodingHeartbeatApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, live_encoding_heartbeat_webhook, **kwargs):
        # type: (LiveEncodingHeartbeatWebhook, dict) -> LiveEncodingHeartbeatWebhook
        """Add &#39;Live Encoding Heartbeat&#39; Webhook

        :param live_encoding_heartbeat_webhook: The &#39;Live Encoding Heartbeat&#39; Webhook to be added.
        :type live_encoding_heartbeat_webhook: LiveEncodingHeartbeatWebhook, required
        :return: Webhook Details
        :rtype: LiveEncodingHeartbeatWebhook
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/live-encoding-heartbeat',
            live_encoding_heartbeat_webhook,
            type=LiveEncodingHeartbeatWebhook,
            **kwargs
        )

    def delete_by_webhook_id(self, webhook_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete &#39;Live Encoding Heartbeat&#39; Webhook

        :param webhook_id: Id of the webhook
        :type webhook_id: string_types, required
        :return: Id of the webhook
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/notifications/webhooks/encoding/encodings/live-encoding-heartbeat/{webhook_id}',
            path_params={'webhook_id': webhook_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get_by_webhook_id(self, webhook_id, **kwargs):
        # type: (string_types, dict) -> LiveEncodingHeartbeatWebhook
        """&#39;Live Encoding Heartbeat&#39; Webhook Details

        :param webhook_id: Id of the webhook
        :type webhook_id: string_types, required
        :return: Webhook Details
        :rtype: LiveEncodingHeartbeatWebhook
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/encodings/live-encoding-heartbeat/{webhook_id}',
            path_params={'webhook_id': webhook_id},
            type=LiveEncodingHeartbeatWebhook,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (LiveEncodingHeartbeatWebhookListQueryParams, dict) -> LiveEncodingHeartbeatWebhook
        """List &#39;Live Encoding Heartbeat&#39; Webhooks

        :param query_params: Query parameters
        :type query_params: LiveEncodingHeartbeatWebhookListQueryParams
        :return: List of 'Live Encoding Heartbeat' Webhooks
        :rtype: LiveEncodingHeartbeatWebhook
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/encodings/live-encoding-heartbeat',
            query_params=query_params,
            pagination_response=True,
            type=LiveEncodingHeartbeatWebhook,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PcmChannelLayout(Enum):
    MONO = "MONO"
    STEREO = "STEREO"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_standby_pool_encoding_manifest_type import LiveStandbyPoolEncodingManifestType
import pprint
import six


class LiveStandbyPoolEncodingManifest(object):
    @poscheck_model
    def __init__(self,
                 url=None,
                 manifest_id=None,
                 type_=None):
        # type: (string_types, string_types, LiveStandbyPoolEncodingManifestType) -> None

        self._url = None
        self._manifest_id = None
        self._type = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if manifest_id is not None:
            self.manifest_id = manifest_id
        if type_ is not None:
            self.type = type_

    @property
    def openapi_types(self):
        types = {
            'url': 'string_types',
            'manifest_id': 'string_types',
            'type': 'LiveStandbyPoolEncodingManifestType'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'url': 'url',
            'manifest_id': 'manifestId',
            'type': 'type'
        }
        return attributes

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this LiveStandbyPoolEncodingManifest.

        URL to the manifest

        :return: The url of this LiveStandbyPoolEncodingManifest.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this LiveStandbyPoolEncodingManifest.

        URL to the manifest

        :param url: The url of this LiveStandbyPoolEncodingManifest.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def manifest_id(self):
        # type: () -> string_types
        """Gets the manifest_id of this LiveStandbyPoolEncodingManifest.

        ID of the manifest that was created for the encoding

        :return: The manifest_id of this LiveStandbyPoolEncodingManifest.
        :rtype: string_types
        """
        return self._manifest_id

    @manifest_id.setter
    def manifest_id(self, manifest_id):
        # type: (string_types) -> None
        """Sets the manifest_id of this LiveStandbyPoolEncodingManifest.

        ID of the manifest that was created for the encoding

        :param manifest_id: The manifest_id of this LiveStandbyPoolEncodingManifest.
        :type: string_types
        """

        if manifest_id is not None:
            if not isinstance(manifest_id, string_types):
                raise TypeError("Invalid type for `manifest_id`, type has to be `string_types`")

        self._manifest_id = manifest_id

    @property
    def type(self):
        # type: () -> LiveStandbyPoolEncodingManifestType
        """Gets the type of this LiveStandbyPoolEncodingManifest.


        :return: The type of this LiveStandbyPoolEncodingManifest.
        :rtype: LiveStandbyPoolEncodingManifestType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (LiveStandbyPoolEncodingManifestType) -> None
        """Sets the type of this LiveStandbyPoolEncodingManifest.


        :param type_: The type of this LiveStandbyPoolEncodingManifest.
        :type: LiveStandbyPoolEncodingManifestType
        """

        if type_ is not None:
            if not isinstance(type_, LiveStandbyPoolEncodingManifestType):
                raise TypeError("Invalid type for `type`, type has to be `LiveStandbyPoolEncodingManifestType`")

        self._type = type_

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveStandbyPoolEncodingManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class OrganizationPendingInvitation(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 email=None,
                 group_id=None,
                 group_name=None):
        # type: (string_types, string_types, string_types, string_types) -> None

        self._id = None
        self._email = None
        self._group_id = None
        self._group_name = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if email is not None:
            self.email = email
        if group_id is not None:
            self.group_id = group_id
        if group_name is not None:
            self.group_name = group_name

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'email': 'string_types',
            'group_id': 'string_types',
            'group_name': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'email': 'email',
            'group_id': 'groupId',
            'group_name': 'groupName'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this OrganizationPendingInvitation.

        Id of Tenant (required)

        :return: The id of this OrganizationPendingInvitation.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this OrganizationPendingInvitation.

        Id of Tenant (required)

        :param id_: The id of this OrganizationPendingInvitation.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def email(self):
        # type: () -> string_types
        """Gets the email of this OrganizationPendingInvitation.

        Email of Tenant (required)

        :return: The email of this OrganizationPendingInvitation.
        :rtype: string_types
        """
        return self._email

    @email.setter
    def email(self, email):
        # type: (string_types) -> None
        """Sets the email of this OrganizationPendingInvitation.

        Email of Tenant (required)

        :param email: The email of this OrganizationPendingInvitation.
        :type: string_types
        """

        if email is not None:
            if not isinstance(email, string_types):
                raise TypeError("Invalid type for `email`, type has to be `string_types`")

        self._email = email

    @property
    def group_id(self):
        # type: () -> string_types
        """Gets the group_id of this OrganizationPendingInvitation.

        Id of group (required)

        :return: The group_id of this OrganizationPendingInvitation.
        :rtype: string_types
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        # type: (string_types) -> None
        """Sets the group_id of this OrganizationPendingInvitation.

        Id of group (required)

        :param group_id: The group_id of this OrganizationPendingInvitation.
        :type: string_types
        """

        if group_id is not None:
            if not isinstance(group_id, string_types):
                raise TypeError("Invalid type for `group_id`, type has to be `string_types`")

        self._group_id = group_id

    @property
    def group_name(self):
        # type: () -> string_types
        """Gets the group_name of this OrganizationPendingInvitation.

        Name of group (required)

        :return: The group_name of this OrganizationPendingInvitation.
        :rtype: string_types
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        # type: (string_types) -> None
        """Sets the group_name of this OrganizationPendingInvitation.

        Name of group (required)

        :param group_name: The group_name of this OrganizationPendingInvitation.
        :type: string_types
        """

        if group_name is not None:
            if not isinstance(group_name, string_types):
                raise TypeError("Invalid type for `group_name`, type has to be `string_types`")

        self._group_name = group_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationPendingInvitation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cdn_provider import CdnProvider
from bitmovin_api_sdk.models.output import Output
import pprint
import six


class CdnOutput(Output):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 acl=None,
                 domain_name=None,
                 cdn_provider=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[AclEntry], string_types, CdnProvider) -> None
        super(CdnOutput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, acl=acl)

        self._domain_name = None
        self._cdn_provider = None
        self.discriminator = None

        if domain_name is not None:
            self.domain_name = domain_name
        if cdn_provider is not None:
            self.cdn_provider = cdn_provider

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(CdnOutput, self), 'openapi_types'):
            types = getattr(super(CdnOutput, self), 'openapi_types')

        types.update({
            'domain_name': 'string_types',
            'cdn_provider': 'CdnProvider'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(CdnOutput, self), 'attribute_map'):
            attributes = getattr(super(CdnOutput, self), 'attribute_map')

        attributes.update({
            'domain_name': 'domainName',
            'cdn_provider': 'cdnProvider'
        })
        return attributes

    @property
    def domain_name(self):
        # type: () -> string_types
        """Gets the domain_name of this CdnOutput.

        Domain name for public access to CDN content

        :return: The domain_name of this CdnOutput.
        :rtype: string_types
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        # type: (string_types) -> None
        """Sets the domain_name of this CdnOutput.

        Domain name for public access to CDN content

        :param domain_name: The domain_name of this CdnOutput.
        :type: string_types
        """

        if domain_name is not None:
            if not isinstance(domain_name, string_types):
                raise TypeError("Invalid type for `domain_name`, type has to be `string_types`")

        self._domain_name = domain_name

    @property
    def cdn_provider(self):
        # type: () -> CdnProvider
        """Gets the cdn_provider of this CdnOutput.

        CDN Provider of the Output

        :return: The cdn_provider of this CdnOutput.
        :rtype: CdnProvider
        """
        return self._cdn_provider

    @cdn_provider.setter
    def cdn_provider(self, cdn_provider):
        # type: (CdnProvider) -> None
        """Sets the cdn_provider of this CdnOutput.

        CDN Provider of the Output

        :param cdn_provider: The cdn_provider of this CdnOutput.
        :type: CdnProvider
        """

        if cdn_provider is not None:
            if not isinstance(cdn_provider, CdnProvider):
                raise TypeError("Invalid type for `cdn_provider`, type has to be `CdnProvider`")

        self._cdn_provider = cdn_provider

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(CdnOutput, self), "to_dict"):
            result = super(CdnOutput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CdnOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_mix_source_channel_type import AudioMixSourceChannelType
import pprint
import six


class AudioMixInputStreamSourceChannel(object):
    @poscheck_model
    def __init__(self,
                 gain=None,
                 type_=None,
                 channel_number=None):
        # type: (float, AudioMixSourceChannelType, int) -> None

        self._gain = None
        self._type = None
        self._channel_number = None
        self.discriminator = None

        if gain is not None:
            self.gain = gain
        if type_ is not None:
            self.type = type_
        if channel_number is not None:
            self.channel_number = channel_number

    @property
    def openapi_types(self):
        types = {
            'gain': 'float',
            'type': 'AudioMixSourceChannelType',
            'channel_number': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'gain': 'gain',
            'type': 'type',
            'channel_number': 'channelNumber'
        }
        return attributes

    @property
    def gain(self):
        # type: () -> float
        """Gets the gain of this AudioMixInputStreamSourceChannel.

        Gain for this source channel. Default is 1.0.

        :return: The gain of this AudioMixInputStreamSourceChannel.
        :rtype: float
        """
        return self._gain

    @gain.setter
    def gain(self, gain):
        # type: (float) -> None
        """Sets the gain of this AudioMixInputStreamSourceChannel.

        Gain for this source channel. Default is 1.0.

        :param gain: The gain of this AudioMixInputStreamSourceChannel.
        :type: float
        """

        if gain is not None:
            if not isinstance(gain, (float, int)):
                raise TypeError("Invalid type for `gain`, type has to be `float`")

        self._gain = gain

    @property
    def type(self):
        # type: () -> AudioMixSourceChannelType
        """Gets the type of this AudioMixInputStreamSourceChannel.


        :return: The type of this AudioMixInputStreamSourceChannel.
        :rtype: AudioMixSourceChannelType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (AudioMixSourceChannelType) -> None
        """Sets the type of this AudioMixInputStreamSourceChannel.


        :param type_: The type of this AudioMixInputStreamSourceChannel.
        :type: AudioMixSourceChannelType
        """

        if type_ is not None:
            if not isinstance(type_, AudioMixSourceChannelType):
                raise TypeError("Invalid type for `type`, type has to be `AudioMixSourceChannelType`")

        self._type = type_

    @property
    def channel_number(self):
        # type: () -> int
        """Gets the channel_number of this AudioMixInputStreamSourceChannel.

        Number of this source channel. If type is 'CHANNEL_NUMBER', this must be set.

        :return: The channel_number of this AudioMixInputStreamSourceChannel.
        :rtype: int
        """
        return self._channel_number

    @channel_number.setter
    def channel_number(self, channel_number):
        # type: (int) -> None
        """Sets the channel_number of this AudioMixInputStreamSourceChannel.

        Number of this source channel. If type is 'CHANNEL_NUMBER', this must be set.

        :param channel_number: The channel_number of this AudioMixInputStreamSourceChannel.
        :type: int
        """

        if channel_number is not None:
            if not isinstance(channel_number, int):
                raise TypeError("Invalid type for `channel_number`, type has to be `int`")

        self._channel_number = channel_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioMixInputStreamSourceChannel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class LiveStandbyPoolEventLogListQueryParams(object):
    def __init__(self, offset=None, limit=None, sort=None, event_type=None):
        # type: (int, int, string_types, string_types) -> None
        super(LiveStandbyPoolEventLogListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit
        self.sort = sort
        self.event_type = event_type

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int',
            'sort': 'string_types',
            'event_type': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit',
            'sort': 'sort',
            'event_type': 'eventType'
        }

        return attributes



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input import Input
from bitmovin_api_sdk.models.s3_access_style import S3AccessStyle
from bitmovin_api_sdk.models.s3_signature_version import S3SignatureVersion
import pprint
import six


class GenericS3Input(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bucket_name=None,
                 host=None,
                 port=None,
                 ssl=None,
                 signing_region=None,
                 signature_version=None,
                 access_key=None,
                 secret_key=None,
                 access_style=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, int, bool, string_types, S3SignatureVersion, string_types, string_types, S3AccessStyle) -> None
        super(GenericS3Input, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._bucket_name = None
        self._host = None
        self._port = None
        self._ssl = None
        self._signing_region = None
        self._signature_version = None
        self._access_key = None
        self._secret_key = None
        self._access_style = None
        self.discriminator = None

        if bucket_name is not None:
            self.bucket_name = bucket_name
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if ssl is not None:
            self.ssl = ssl
        if signing_region is not None:
            self.signing_region = signing_region
        if signature_version is not None:
            self.signature_version = signature_version
        if access_key is not None:
            self.access_key = access_key
        if secret_key is not None:
            self.secret_key = secret_key
        if access_style is not None:
            self.access_style = access_style

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(GenericS3Input, self), 'openapi_types'):
            types = getattr(super(GenericS3Input, self), 'openapi_types')

        types.update({
            'bucket_name': 'string_types',
            'host': 'string_types',
            'port': 'int',
            'ssl': 'bool',
            'signing_region': 'string_types',
            'signature_version': 'S3SignatureVersion',
            'access_key': 'string_types',
            'secret_key': 'string_types',
            'access_style': 'S3AccessStyle'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(GenericS3Input, self), 'attribute_map'):
            attributes = getattr(super(GenericS3Input, self), 'attribute_map')

        attributes.update({
            'bucket_name': 'bucketName',
            'host': 'host',
            'port': 'port',
            'ssl': 'ssl',
            'signing_region': 'signingRegion',
            'signature_version': 'signatureVersion',
            'access_key': 'accessKey',
            'secret_key': 'secretKey',
            'access_style': 'accessStyle'
        })
        return attributes

    @property
    def bucket_name(self):
        # type: () -> string_types
        """Gets the bucket_name of this GenericS3Input.

        Your generic S3 bucket name (required)

        :return: The bucket_name of this GenericS3Input.
        :rtype: string_types
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        # type: (string_types) -> None
        """Sets the bucket_name of this GenericS3Input.

        Your generic S3 bucket name (required)

        :param bucket_name: The bucket_name of this GenericS3Input.
        :type: string_types
        """

        if bucket_name is not None:
            if not isinstance(bucket_name, string_types):
                raise TypeError("Invalid type for `bucket_name`, type has to be `string_types`")

        self._bucket_name = bucket_name

    @property
    def host(self):
        # type: () -> string_types
        """Gets the host of this GenericS3Input.

        The generic S3 server hostname (or IP address) (required)

        :return: The host of this GenericS3Input.
        :rtype: string_types
        """
        return self._host

    @host.setter
    def host(self, host):
        # type: (string_types) -> None
        """Sets the host of this GenericS3Input.

        The generic S3 server hostname (or IP address) (required)

        :param host: The host of this GenericS3Input.
        :type: string_types
        """

        if host is not None:
            if not isinstance(host, string_types):
                raise TypeError("Invalid type for `host`, type has to be `string_types`")

        self._host = host

    @property
    def port(self):
        # type: () -> int
        """Gets the port of this GenericS3Input.

        The port on which the generic S3 server is running on (if not provided 8000 will be used)

        :return: The port of this GenericS3Input.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        # type: (int) -> None
        """Sets the port of this GenericS3Input.

        The port on which the generic S3 server is running on (if not provided 8000 will be used)

        :param port: The port of this GenericS3Input.
        :type: int
        """

        if port is not None:
            if not isinstance(port, int):
                raise TypeError("Invalid type for `port`, type has to be `int`")

        self._port = port

    @property
    def ssl(self):
        # type: () -> bool
        """Gets the ssl of this GenericS3Input.

        Controls whether SSL is used or not

        :return: The ssl of this GenericS3Input.
        :rtype: bool
        """
        return self._ssl

    @ssl.setter
    def ssl(self, ssl):
        # type: (bool) -> None
        """Sets the ssl of this GenericS3Input.

        Controls whether SSL is used or not

        :param ssl: The ssl of this GenericS3Input.
        :type: bool
        """

        if ssl is not None:
            if not isinstance(ssl, bool):
                raise TypeError("Invalid type for `ssl`, type has to be `bool`")

        self._ssl = ssl

    @property
    def signing_region(self):
        # type: () -> string_types
        """Gets the signing_region of this GenericS3Input.

        The signing region to use

        :return: The signing_region of this GenericS3Input.
        :rtype: string_types
        """
        return self._signing_region

    @signing_region.setter
    def signing_region(self, signing_region):
        # type: (string_types) -> None
        """Sets the signing_region of this GenericS3Input.

        The signing region to use

        :param signing_region: The signing_region of this GenericS3Input.
        :type: string_types
        """

        if signing_region is not None:
            if not isinstance(signing_region, string_types):
                raise TypeError("Invalid type for `signing_region`, type has to be `string_types`")

        self._signing_region = signing_region

    @property
    def signature_version(self):
        # type: () -> S3SignatureVersion
        """Gets the signature_version of this GenericS3Input.

        Specifies the method used for authentication

        :return: The signature_version of this GenericS3Input.
        :rtype: S3SignatureVersion
        """
        return self._signature_version

    @signature_version.setter
    def signature_version(self, signature_version):
        # type: (S3SignatureVersion) -> None
        """Sets the signature_version of this GenericS3Input.

        Specifies the method used for authentication

        :param signature_version: The signature_version of this GenericS3Input.
        :type: S3SignatureVersion
        """

        if signature_version is not None:
            if not isinstance(signature_version, S3SignatureVersion):
                raise TypeError("Invalid type for `signature_version`, type has to be `S3SignatureVersion`")

        self._signature_version = signature_version

    @property
    def access_key(self):
        # type: () -> string_types
        """Gets the access_key of this GenericS3Input.

        Your generic S3 access key (required)

        :return: The access_key of this GenericS3Input.
        :rtype: string_types
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        # type: (string_types) -> None
        """Sets the access_key of this GenericS3Input.

        Your generic S3 access key (required)

        :param access_key: The access_key of this GenericS3Input.
        :type: string_types
        """

        if access_key is not None:
            if not isinstance(access_key, string_types):
                raise TypeError("Invalid type for `access_key`, type has to be `string_types`")

        self._access_key = access_key

    @property
    def secret_key(self):
        # type: () -> string_types
        """Gets the secret_key of this GenericS3Input.

        Your generic S3 secret key (required)

        :return: The secret_key of this GenericS3Input.
        :rtype: string_types
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        # type: (string_types) -> None
        """Sets the secret_key of this GenericS3Input.

        Your generic S3 secret key (required)

        :param secret_key: The secret_key of this GenericS3Input.
        :type: string_types
        """

        if secret_key is not None:
            if not isinstance(secret_key, string_types):
                raise TypeError("Invalid type for `secret_key`, type has to be `string_types`")

        self._secret_key = secret_key

    @property
    def access_style(self):
        # type: () -> S3AccessStyle
        """Gets the access_style of this GenericS3Input.

        Specifies the URL access style to use

        :return: The access_style of this GenericS3Input.
        :rtype: S3AccessStyle
        """
        return self._access_style

    @access_style.setter
    def access_style(self, access_style):
        # type: (S3AccessStyle) -> None
        """Sets the access_style of this GenericS3Input.

        Specifies the URL access style to use

        :param access_style: The access_style of this GenericS3Input.
        :type: S3AccessStyle
        """

        if access_style is not None:
            if not isinstance(access_style, S3AccessStyle):
                raise TypeError("Invalid type for `access_style`, type has to be `S3AccessStyle`")

        self._access_style = access_style

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(GenericS3Input, self), "to_dict"):
            result = super(GenericS3Input, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenericS3Input):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
